@@ -219,8 +219,8 @@ QVariantList MultiDayIncidenceModel::layoutLines(const QDate &rowStart) const
 
 void MultiDayIncidenceModel::resetLayoutLines()
 {
-    if(mSourceModel->calendar()->isLoading()) {
-        if(!mRefreshTimer.isActive()) {
+    if (mSourceModel->calendar()->isLoading()) {
+        if (!mRefreshTimer.isActive()) {
             mRefreshTimer.start(100);
         }
         return;
@@ -233,7 +233,7 @@ void MultiDayIncidenceModel::resetLayoutLines()
     const auto numPeriods = rowCount({});
     m_laidOutLines.reserve(numPeriods);
 
-    for(int i = 0; i < numPeriods; ++i) {
+    for (int i = 0; i < numPeriods; ++i) {
         const auto periodStart = mSourceModel->start().addDays(i * mPeriodLength);
         const auto periodIncidenceLayout = layoutLines(periodStart);
         m_laidOutLines.append(periodIncidenceLayout);
@@ -249,8 +249,7 @@ QVariant MultiDayIncidenceModel::data(const QModelIndex &idx, int role) const
     }
 
     switch (role) {
-    case PeriodStartDate:
-    {
+    case PeriodStartDate: {
         const auto rowStart = mSourceModel->start().addDays(idx.row() * mPeriodLength);
         return rowStart.startOfDay();
     }
@@ -294,7 +293,7 @@ void MultiDayIncidenceModel::setModel(IncidenceOccurrenceModel *model)
 
 void MultiDayIncidenceModel::slotSourceDataChanged(const QModelIndex &upperLeft, const QModelIndex &bottomRight)
 {
-    if(!upperLeft.isValid() || !bottomRight.isValid()) {
+    if (!upperLeft.isValid() || !bottomRight.isValid()) {
         return;
     }
 
@@ -323,7 +322,7 @@ void MultiDayIncidenceModel::scheduleLayoutLinesUpdates(const QModelIndex &sourc
     }
 
     for (int i = sourceFirstRow; i <= sourceLastRow; ++i) {
-        if(m_linesToUpdate.count() == m_laidOutLines.count()) {
+        if (m_linesToUpdate.count() == m_laidOutLines.count()) {
             break;
         }
 
@@ -337,7 +336,7 @@ void MultiDayIncidenceModel::scheduleLayoutLinesUpdates(const QModelIndex &sourc
         const auto firstPeriodOccurrenceAppears = startDaysFromSourceStart / mPeriodLength;
         const auto lastPeriodOccurrenceAppears = endDaysFromSourceStart / mPeriodLength;
 
-        if(firstPeriodOccurrenceAppears > m_laidOutLines.count() || lastPeriodOccurrenceAppears < 0) {
+        if (firstPeriodOccurrenceAppears > m_laidOutLines.count() || lastPeriodOccurrenceAppears < 0) {
             continue;
         }
 
@@ -358,7 +357,7 @@ void MultiDayIncidenceModel::scheduleLayoutLinesUpdates(const QModelIndex &sourc
 
 void MultiDayIncidenceModel::updateScheduledLayoutLines()
 {
-    for (const auto lineIndex : m_linesToUpdate) {
+    for (const auto lineIndex : std::as_const(m_linesToUpdate)) {
         const auto periodStart = mSourceModel->start().addDays(lineIndex * mPeriodLength);
         const auto idx = index(lineIndex, 0);
         const auto laidOutLine = layoutLines(periodStart);
@@ -393,6 +392,23 @@ void MultiDayIncidenceModel::setFilters(MultiDayIncidenceModel::Filters filters)
     endResetModel();
 }
 
+bool MultiDayIncidenceModel::showTodos() const
+{
+    return m_showTodos;
+}
+
+void MultiDayIncidenceModel::setShowTodos(const bool showTodos)
+{
+    if (showTodos == m_showTodos) {
+        return;
+    }
+
+    m_showTodos = showTodos;
+    Q_EMIT showTodosChanged();
+
+    resetLayoutLines();
+}
+
 bool MultiDayIncidenceModel::showSubTodos() const
 {
     return m_showSubTodos;
@@ -412,12 +428,16 @@ void MultiDayIncidenceModel::setShowSubTodos(const bool showSubTodos)
 
 bool MultiDayIncidenceModel::incidencePassesFilter(const QModelIndex &idx) const
 {
-    if (!m_filters && m_showSubTodos) {
+    if (!m_filters && m_showTodos && m_showSubTodos) {
         return true;
     }
-    bool include = false;
+
+    bool include = true;
 
     if (m_filters) {
+        // Start out assuming the worst, filter everything out
+        include = false;
+
         const auto start = idx.data(IncidenceOccurrenceModel::StartTime).toDateTime().date();
 
         if (m_filters.testFlag(AllDayOnly) && idx.data(IncidenceOccurrenceModel::AllDay).toBool()) {
@@ -427,14 +447,18 @@ bool MultiDayIncidenceModel::incidencePassesFilter(const QModelIndex &idx) const
         if (m_filters.testFlag(NoStartDateOnly) && !start.isValid()) {
             include = true;
         }
+
         if (m_filters.testFlag(MultiDayOnly) && idx.data(IncidenceOccurrenceModel::Duration).value<KCalendarCore::Duration>().asDays() >= 1) {
             include = true;
         }
     }
 
-    if (!m_showSubTodos
-        && idx.data(IncidenceOccurrenceModel::IncidencePtr).value<KCalendarCore::Incidence::Ptr>()->relatedTo().isEmpty()) {
-        include = true;
+    const auto incidencePtr = idx.data(IncidenceOccurrenceModel::IncidencePtr).value<KCalendarCore::Incidence::Ptr>();
+    const auto incidenceIsTodo = incidencePtr->type() == Incidence::TypeTodo;
+    if (!m_showTodos && incidenceIsTodo) {
+        include = false;
+    } else if (m_showTodos && incidenceIsTodo && !m_showSubTodos && !incidencePtr->relatedTo().isEmpty()) {
+        include = false;
     }
 
     return include;
